//
// This code is part of https://developer.mescius.com/document-solutions/dot-net-pdf-api/demos.
// Copyright (c) MESCIUS inc. All rights reserved.
//
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;

namespace DsPdfWeb.Demos
{
    // This sample demonstrates graphical signature feature with support API
    // provided by the server running DsPdf. The Annotation Editor's default toolbar 
    // layout contains a new toolbar button, "Signature tool".

    // This and other samples in this section demonstrate the features of GcPdfViewer
    // (a JavaScript PDF viewer control included with DsPdf), mainly the ability
    // to change PDF files (add or edit annotations and AcroForm fields, rotate pages etc.)
    // when the JS viewer on the client is supported by DsPdf running on the server.
    //
    // To enable the editing features of the viewer, its supportApi property must be set
    // to a URL on the server that implements all or some of the edit supporting APIs
    // that are known to/expected by the viewer. This DsPdf demo site provides those APIs,
    // which makes it possible to demonstrate the editing when you open the PDF viewer
    // in this sample. When you download this sample, in addition to the .NET Core
    // console app project that generates the sample PDF, an ASP.NET Core project is
    // also included in the download zip (located in the GcPdfViewerWeb sub-folder of the
    // downloaded zip), which also provides the necessary APIs. In particular, it includes
    // a project that implements the APIs and provides them via a special controller.
    // It is actually the same controller that is used by this DsPdf demo site, and which
    // can be used in any ASP.NET Core site to enable the viewer editing features.
    //
    // Look at the following files in the sample download zip for more info:
    // - GcPdfViewerWeb\SupportApiDemo: the sample ASP.NET Core web site.
    // - GcPdfViewerWeb\SupportApiDemo.sln: solution to build/run the sample web site.
    // - GcPdfViewerWeb\SupportApi: support API implementation (can be used in any site).
    // - GcPdfViewerWeb\SupportApi\Controllers\GcPdfViewerController.cs: support API controller.
    // 
    // Please note that this and other samples in this section are only available in C# at this time.
    //

    
    public class ViewerAddSignatureFromToolbar
    {
        public void CreatePDF(Stream stream)
        {
            var doc = new GcPdfDocument();
            using var fs = File.OpenRead(Path.Combine("Resources", "PDFs", "Simple-Lease-Agreement.pdf"));
            doc.Load(fs);
            doc.Save(stream);
        }

        public const string JS_CODE = @"
var viewer;

function applyNormalViewerLayout() {
    viewer.toolbarLayout.viewer = {
        default: ['save', 'edit-sign-tool', 'doc-title', '$split', 'about'],
        mobile: ['save', 'edit-sign-tool', 'doc-title', '$split', 'about'],
        fullscreen: ['$fullscreen', 'save', 'edit-sign-tool', 'doc-title', '$split', 'about']
    };
    viewer.applyToolbarLayout();
}

function applySignedViewerLayout() {
    viewer.toolbarLayout.viewer = {
        default: ['save', 'doc-title', '$split', 'about'],
        mobile: ['save', 'doc-title', '$split', 'about'],
        fullscreen: ['$fullscreen', 'save', 'doc-title', '$split', 'about']
    };
    viewer.applyToolbarLayout();
}

function onSignatureAdded(resultDetails) {
            viewer.scrollAnnotationIntoView(resultDetails.pageIndex, resultDetails.annotation);
            applySignedViewerLayout();
}

function createPdfViewer(selector, baseOptions) {
    var options = baseOptions || {};
    if (!options.supportApi) {
        options.supportApi = {
            apiUrl: (window.__baseUrl || '') + 'support-api/gc-pdf-viewer',
            token: window.afToken || '',
            webSocketUrl: false, suppressInfoMessages: true, suppressErrorMessages: true
        };
    }

    options.signTool = {
        selectedTab: 'Draw',
        saveSignature: false,
        penColor: '#000000',
        penWidth: 2,
        hideSaveSignature: true,
        canvasSize: { width: 480, height: 168 },
        autoResizeCanvas: false,
        destinationScale: 0.33,
        afterAdd: function (result) {
            onSignatureAdded(result);
            return true;
        },
        location: { x: 87, y: 116 },
        title: 'Landlord/Lessor',
    };
    options.restoreViewStateOnLoad = false;
    viewer = new GcPdfViewer(selector, options);
    viewer.mouseMode = 1;
    viewer.addDefaultPanels();
    viewer.addAnnotationEditorPanel();
    viewer.zoom = 70;
    applyNormalViewerLayout();
    return viewer;
}
";

    }
}
